@@ -22,7 +22,7 @@ from psycopg2 import ProgrammingError
 from psycopg2 import NotSupportedError
 
 
-__version__ = VERSION = version = '1.0.1'
+__version__ = VERSION = version = '1.0.2'
 
 from .pubsub import PubSub
 
@@ -30,9 +30,9 @@ from .pubsub import PubSub
 class Connection(object):
     def __init__(self, host_or_url=None, database=None, user=None, password=None, port=5432, 
                        search_path=None, timezone="+00"):
-        self.logging = False
+        self.logging = (os.getenv('DEBUG')=='TRUE')
         if host_or_url is None:
-            host_or_url = os.getenv('TORNPSQL', "127.0.0.1")
+            host_or_url = os.getenv('DATABASE_URL', "127.0.0.1")
         if host_or_url.startswith('postgres://'):
             try:
                 args = re.search('postgres://(?P<user>[\w\-]*):?(?P<password>[\w\-]*)@(?P<host>[\w\-\.]+):?(?P<port>\d+)/?(?P<database>[\w\-]+)', host_or_url).groupdict()
@@ -125,7 +125,7 @@ class Connection(object):
         """Returns a row list for the given query and parameters."""
         cursor = self._cursor()
         try:
-            self._execute(cursor, query, parameters, kwargs)    
+            self._execute(cursor, query, parameters or None, kwargs)    
             if cursor.description:
                 column_names = [column.name for column in cursor.description]
                 return [Row(itertools.izip(column_names, row)) for row in cursor.fetchall()]
@@ -153,6 +153,9 @@ class Connection(object):
         cursor = self._cursor()
         try:
             self._executemany(cursor, query, parameters)
+            if cursor.description:
+                column_names = [column.name for column in cursor.description]
+                return [Row(itertools.izip(column_names, row)) for row in cursor.fetchall()]
         except Exception: # pragma: no cover
             cursor.close()
             raise
@@ -180,28 +183,31 @@ class Connection(object):
             query = self._set_search_path(query)
             if kwargs:
                 query = query % dict(map(lambda r: (r[0], adapt(r[1])), kwargs.items()))
-                if self.logging: self._log(query)
+                self._log(query)
                 cursor.execute(query)
             else:
-                if self.logging: self._log(cursor.mogrify(query, parameters))
+                self._log(query, parameters)
                 cursor.execute(query, parameters)
 
-        except psycopg2.OperationalError as e: # pragma: no cover
+        except OperationalError as e: # pragma: no cover
             logging.error("Error connecting to PostgreSQL on %s, %s", self.host, e)
             self.close()
             raise
 
-    def _log(self, query):    
-        logging.info(re.sub(r"\n\s*", " ", query))
+    def _log(self, query, params=None):    
+        if self.logging: 
+            if params:
+                query = self.mogrify(query, *params)
+            logging.info(re.sub(r"\n\s*", " ", query))
 
     def _executemany(self, cursor, query, parameters):
         """The function is mostly useful for commands that update the database: 
            any result set returned by the query is discarded."""
         try:
-            query = self._set_search_path(query)
-            if self.logging: self._log(query)
+            query = self._set_search_path(query)    
+            self._log(query)
             cursor.executemany(query, parameters)
-        except psycopg2.OperationalError as e: # pragma: no cover
+        except OperationalError as e: # pragma: no cover
             logging.error("Error connecting to PostgreSQL on %s, e", self.host, e)
             self.close()
             raise 
